==> onos-yang-serializers-xml-2.3-sources.jar: org/onosproject/yang/gen/v1/yangautoprefixlist/rev20160624/yangautoprefixlist/c2/DefaultL2.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.yangautoprefixlist.c2;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of l2.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL2 extends InnerModelObject 
        implements L2, MultiInstanceObject<L2Keys> {
    protected String m1;
    protected String m2;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String m1() {
        return m1;
    }

    @Override
    public String m2() {
        return m2;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void m1(String m1) {
        valueLeafFlags.set(LeafIdentifier.M1.getLeafIndex());
        this.m1 = m1;
    }

    @Override
    public void m2(String m2) {
        valueLeafFlags.set(LeafIdentifier.M2.getLeafIndex());
        this.m2 = m2;
    }

    @Override
    public int hashCode() {
        return Objects.hash(m1, m2, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL2) {
            DefaultL2 other = (DefaultL2) obj;
            return
                Objects.equals(m1, other.m1) &&
                Objects.equals(m2, other.m2) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("m1=" + m1)
            .add("m2=" + m2)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultL2.
     */
    public DefaultL2() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yangautoprefixlist/rev20160624/yangautoprefixlist/c2/DefaultL2.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.yangautoprefixlist.c2;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of l2.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL2 extends InnerModelObject 
        implements L2, MultiInstanceObject<L2Keys> {
    protected String m1;
    protected String m2;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String m1() {
        return m1;
    }

    @Override
    public String m2() {
        return m2;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void m1(String m1) {
        valueLeafFlags.set(LeafIdentifier.M1.getLeafIndex());
        this.m1 = m1;
    }

    @Override
    public void m2(String m2) {
        valueLeafFlags.set(LeafIdentifier.M2.getLeafIndex());
        this.m2 = m2;
    }

    @Override
    public int hashCode() {
        return Objects.hash(m1, m2, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL2) {
            DefaultL2 other = (DefaultL2) obj;
            return
                Objects.deepEquals(m1, other.m1) &&
                Objects.deepEquals(m2, other.m2) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("m1=" + m1)
            .add("m2=" + m2)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultL2.
     */
    public DefaultL2() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
